@@ -1,6 +1,6 @@
 __author__ = """Arkadiusz Michał Ryś"""
 __email__ = "Arkadiusz.Michal.Rys@gmail.com"
-__version__ = "0.1.0"
+__version__ = "0.2.0"
 
 from arklog.logging import (
     CRITICAL,
@@ -16,6 +16,8 @@ from arklog.logging import (
     set_defaults,
     set_from_file,
     log,
+    success,
+    extra,
 )
 
 from logging import (
