@@ -1,15 +1,17 @@
+import logging
+import pathlib
+import types
+from functools import wraps, partial
 from typing import Callable
 
 import yaml
-import logging
-from functools import wraps, partial
-import pathlib
 
 CRITICAL = logging.CRITICAL
 ERROR = logging.ERROR
 WARNING = logging.WARNING
+SUCCESS = 21
 INFO = logging.INFO
-EXTRA = 15
+EXTRA = 11
 DEBUG = logging.DEBUG
 NOTSET = logging.NOTSET
 
@@ -36,8 +38,9 @@ class ColorFormatter(logging.Formatter):
 
     COLORS = {
         DEBUG: BLUE,
-        EXTRA: GREEN,
+        EXTRA: LIGHTPURPLE,
         INFO: WHITE,
+        SUCCESS: GREEN,
         WARNING: YELLOW,
         ERROR: LIGHTRED,
         CRITICAL: RED,
@@ -49,13 +52,25 @@ class ColorFormatter(logging.Formatter):
         return f"{color}{logging.Formatter.format(self, record)}{self.NC}"
 
 
+def add_logger_methods():
+    """"""
+    logging.Logger.success = types.MethodType(success_wrap, logging.Logger)
+    logging.RootLogger.success = types.MethodType(success_wrap, logging.RootLogger)
+    logging.Logger.extra = types.MethodType(extra_wrap, logging.Logger)
+    logging.RootLogger.extra = types.MethodType(extra_wrap, logging.RootLogger)
+
+
 def create_logger(name: str, level: int = logging.DEBUG, file_path: pathlib.Path = None) -> logging.Logger:
     """
     Create logger instance.
     The logger will output to stdout if no file_path is provided.
     """
+    add_logger_methods()
+
     logger = logging.getLogger(name)
     logger.setLevel(level)
+    logger.success = types.MethodType(success_wrap, logger)
+    logger.extra = types.MethodType(extra_wrap, logger)
     formatter = ColorFormatter(fmt="%(message)s")
 
     # Don't add colors when logging to a file because they will not be displayed
@@ -72,6 +87,8 @@ def create_logger(name: str, level: int = logging.DEBUG, file_path: pathlib.Path
 
 def set_defaults(level: int = logging.DEBUG, file_path: [pathlib.Path, str] = None):
     """Set the default logger options."""
+    add_logger_methods()
+
     if file_path:
         logging.basicConfig(
             filename=f"{file_path}",
@@ -92,6 +109,40 @@ def set_defaults(level: int = logging.DEBUG, file_path: [pathlib.Path, str] = No
         )
 
 
+def success_wrap(self, msg, *args, **kwargs):
+    """"""
+    if self.isEnabledFor(SUCCESS):
+        self._log(SUCCESS, msg, args, **kwargs)
+
+
+def success(msg, *args, **kwargs):
+    """"""
+    if len(logging.root.handlers) == 0:
+        set_defaults()
+    try:
+        logging.root.success(msg, *args, **kwargs)
+    except (AttributeError, TypeError):
+        logging.root.success = types.MethodType(success_wrap, logging.root)
+        logging.root.success(msg, *args, **kwargs)
+
+
+def extra_wrap(self, msg, *args, **kwargs):
+    """"""
+    if self.isEnabledFor(EXTRA):
+        self._log(EXTRA, msg, args, **kwargs)
+
+
+def extra(msg, *args, **kwargs):
+    """"""
+    if len(logging.root.handlers) == 0:
+        set_defaults()
+    try:
+        logging.root.extra(msg, *args, **kwargs)
+    except (AttributeError, TypeError):
+        logging.root.extra = types.MethodType(extra_wrap, logging.root)
+        logging.root.extra(msg, *args, **kwargs)
+
+
 def set_from_file(file_path: pathlib.Path):
     """"""
     with file_path.open("rt") as f:
@@ -108,6 +159,7 @@ def attach_wrapper(obj, func=None):
 
 def log(level: int, message: str) -> Callable:
     """Decorator to log."""
+
     def decorate(func: Callable) -> Callable:
         logger = logging.getLogger(func.__module__)
         formatter = logging.Formatter(
